%% CALIBRATION OF STEREOTYPICAL THINKING MODEL

close all;
clear all;

%% PARAMETERS

%inflation
mu    = 2; %Fed's target
sig   = 1.1; %Std. dev. of y/e PCECTPI inflation 1984Q1-2017Q2

%grid
ngp   = 101;
width = 5; %multiples of std. dev
min   = 0.01; %min difference in true distribution

%Inflation expectation differences for Ds and Rs
Dgap  = 1.0; %2016 election
Rgap  = 3.3; %2016 election

%% EXAMPLE PLOT

[dE_st] = expect(mu,sig,ngp,width,0.2,2,1);

%% THETA IMPLIED BY DIFFERENCE IN MEAN INFLATION BETWEEN L & H TYPES

delta   = linspace(min,max(Dgap,Rgap),ngp);
th_outD = zeros(ngp,1);
th_outR = zeros(ngp,1);

for i=1:ngp
    
    %Democrats
    dE_st = @(theta) expect(mu,sig,ngp,width,delta(i),theta,0) - Dgap;
    [theta0,fval,exitflag] = fzero(dE_st,0);    
   
    if exitflag==1
        th_outD(i)  = theta0;
    else
        disp('error')
        break;
    end
    
    %Republicans
    dE_st = @(theta) expect(mu,sig,ngp,width,delta(i),theta,0) - Rgap;
    [theta0,fval,exitflag] = fzero(dE_st,0);    
   
    if exitflag==1
        th_outR(i)  = theta0;
    else
        disp('error')
        break;
    end
       
end

%interpolation
delD = @(theta) interp1(th_outD,delta,theta);
delR = @(theta) interp1(th_outR,delta,theta);

thetaD = @(d) interp1(delta,th_outD,d);
thetaR = @(d) interp1(delta,th_outR,d);

figure;
hold on
[plot_R] = plot(delta,th_outR,'--','Linewidth',2,'Color','k');
[plot_D] = plot(delta,th_outD,'Linewidth',2,'Color','k');
hold off
set(gca,'FontSize',11);
xlim([0 delta(ngp)]);
ylim([0 5]);
xlabel('\delta = E[\pi|q_L] - E[\pi|q_H]');
ylabel('Degree of stereotypical thinking: \theta');
legend([plot_R; plot_D],{'Republicans (2016 election)','Democrats (2016 election)'});
legend boxoff
saveas(gcf,'calibration.pdf');
