%Expectations for Bayesian and stereotypical thinkers given delta, theta
function [dE_st] = expect(mu,sig,ngp,width,delta,theta,MakePlot);

%means for H,L types
muH = mu - delta/2;
muL = mu + delta/2;

%grid
x = linspace(muH-width*sig,muH+width*sig,ngp)';

%density, type-H
if ngp==2
    pH = 0.5.*ones(ngp,1);
elseif ngp>2    
    pH  = zeros(ngp,1);
    pH(1) = normcdf(x(1) + 0.5*(x(2)-x(1)),muH,sig);
    for i = 2:ngp-1
        pH(i) = normcdf(x(i) + 0.5*(x(i+1)-x(i)),muH,sig) - normcdf(x(i) - 0.5*(x(i)-x(i-1)),muH,sig);
    end
    pH(ngp) = 1 - sum(pH(1:ngp-1));
end    

%density, type-L
if ngp==2
    pL    = zeros(ngp,1);
    pL(1) = normcdf(0.5*(x(1)+x(2)),muL,sig);    
    pL(2) = 1 - pL(1);
elseif ngp>2    
    pL  = zeros(ngp,1);
    pL(1) = normcdf(x(1) + 0.5*(x(2)-x(1)),muL,sig);
    for i = 2:ngp-1
        pL(i) = normcdf(x(i) + 0.5*(x(i+1)-x(i)),muL,sig) - normcdf(x(i) - 0.5*(x(i)-x(i-1)),muL,sig);
    end
    pL(ngp) = 1 - sum(pL(1:ngp-1));
end    

%representativeness
r = pL./pH;

%stereotypical densities
pL_st = @(theta) pL.*r.^theta/sum(pL.*r.^theta);
pH_st = @(theta) pH.*r.^-theta/sum(pH.*r.^-theta);

%expected values
EL    = sum(pL.*x);
EH    = sum(pH.*x);

EL_st = sum(pL_st(theta).*x);
EH_st = sum(pH_st(theta).*x);
dE_st = EL_st - EH_st;

if MakePlot==1
   
    figure;
    subplot(1,2,1);
    hold on;
    plot_H = plot(x,pH,'Linewidth',1,'Color','k');
    plot_L = plot(x,pL,'--','Linewidth',1,'Color','k');    
    set(gca,'FontSize',12);
    xlabel('Inflation rate');
    ylabel('Density');
    xlim([x(1) x(end)]);
    legend([plot_H; plot_L],{'q_H','q_L'});
    legend boxoff 
    title('Bayesian thinker (\theta=0)');

    subplot(1,2,2);
    hold on;
    plot_H_st = plot(x,pH_st(theta),'Linewidth',1,'Color','k');
    plot_L_st = plot(x,pL_st(theta),'--','Linewidth',1,'Color','k');
    set(gca,'FontSize',12);
    xlabel('Inflation rate');
    ylabel('Density');    
    xlim([x(1) x(end)]);
    legend([plot_H_st; plot_L_st],{'q_H','q_L'});
    legend boxoff
    title('Stereotypical thinker (\theta=2)');    
    
    h=gcf;
    set(h,'PaperPositionMode','auto');         
    set(h,'PaperOrientation','landscape');
    set(h,'Position',[50 50 1000 600]);    
    print(gcf, '-dpdf', 'density.pdf')
        
end
