* ------------------------------------------------------------------------------
* Melbourne Institute Data, label variables
* ------------------------------------------------------------------------------

* 1-yr inflation expectations
gen px1 = q11a1 if q10a==1 & q10a!=-1
replace px1 = -q11a2 if q10a==2 & q11a2!=-1
replace px1 = 0 if q10a==3
label variable px1 "Year-ahead inflation expectations"

* Gender
rename q1 gender
label variable gender "Gender"
label define gender 1 "male" 2 "female"
label values gender gender

* Age
rename q2 age
label variable age "Age" 
label define age 1 "18-24" 2 "25-34" 3 "34-44" 4 "45-49" 5 "50-54" 6 "55-64" 7 "65+" 8 "Refused"
label values age age
recode age (8=".")

* Education
rename q4 education
label variable education "Education"
recode education (-1=".")
recode education (9=".")
recode education (6=7)
label define education 1 "Primary" 2 "year 10" 3 "Full secondary" 4 "Non-trade cert." 5 "Trade cert." 7 "University" 8 "Post grad." 9 "Refused"
label values education education

* Household income
rename q11 income
recode income (-1=".")
label define income 1 "<20k" 2 "20-30k" 3 "30-40k" 4 "40-50k" 5 "50-60k" 6 "60-70k" 7 "70-80k" 8 "80-90k" 9 "90-100k" 10 ">100k" 11 "Refused"
recode income (11=".")
label values income income

* Occupation
rename q3 occupation
recode occupation (-1=".")
recode occupation (0=".")
label variable occupation "Occupation"
label define occupation 1 "Manager" 2 "Professionals" 3 "Para-professionals" 4 "Trades" 5 "Clerks" 6 "Sales" 7 "Plant & machinery" 8 "Labourer" 9 "Retired" 10 "Unemployed/home duties" 11 "Refused"
label values occupation occupation

* Home ownership status
rename q7 homeOwnership
recode homeOwnership (-1=".")
label variable homeOwnership "Home ownership status"
label define homeOwnership 1 "Rented" 2 "Mortgage" 3 "Outright" 4 "Other" 5 "Refused"
recode homeOwnership (5=".")
label values homeOwnership homeOwnership

* Metro indicator
gen metro = 0 if !missing(loc)
label variable metro "Metropolitan location"
replace metro = 1 if (loc==1 | loc==3 | loc==5 | loc==7 | loc==9 | loc==11 | loc==13)
label define metro 0 "Non-metro" 1 "Metro"
label values metro metro

* Vote
rename q5 vote
recode vote (-1=".")
label variable vote "Federal election voting intention"
recode vote (4=1) (5=4) (7=6) (8=5)
label define vote 1 "Liberal/National" 2 "ALP" 3 "Democrats" 4 "Greens" 5 "One Nation" 6 "Ind/Other/DK"
label values vote vote

* Unemployment expectations
rename q9a unemployment 
recode unemployment (-1=".")
recode unemployment (4=".")
recode unemployment (1=3) (3=1)
label variable unemployment "Unemployment expectations"
label define unemployment 1 "Less" 2 "Same" 3 "More"
label values unemployment unemployment

* Personal income expectations, next year
rename q2a financesNextYr
recode financesNextYr (-1=".")
recode financesNextYr (4=2)
recode financesNextYr (1=3) (3=1)
label variable financesNextYr "Personal finances: next year"
label define financesNextYr 1 "Worse" 2 "Same" 3 "Better"
label values financesNextYr financesNextYr

* Date variable
gen datetemp = .
replace datetemp = 190000 + date if date>=9000
replace datetemp = 200000 + date if date<=9000
gen year = floor(datetemp/100)
gen month = datetemp - year*100
gen date_ym = ym(year,month)
format date_ym %tm

* Survey weights
drop if weight == -1
label variable weight "Sampling weights"

* Keep variables used
keep date date_ym px1 gender age education income occupation homeOwnership metro vote unemployment financesNextYr year month weight
order date date_ym year month
