* ------------------------------------------------------------------------------
* Analysis file: Michigan SCA, cross-section
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Load data
do "${mystart}/Inflation Expectations/Michigan SCA/Code/Load.do"

* Directory to save output
cd "${mystart}/Inflation Expectations/Michigan SCA/Output"

* ------------------------------------------------------------------------------
* Construct main variables
* ------------------------------------------------------------------------------

* Partisanship
gen Republican = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace Republican = 1 if POLAFF==1
gen Democrat = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace Democrat = 1 if POLAFF==2
gen Independent = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace Independent = 1 if POLAFF==3

* Partisanship by strength
gen StrongRep = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace StrongRep = 1 if POLREP==1
gen WeakRep = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace WeakRep = 1 if POLREP==5
gen StrongDem = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace StrongDem = 1 if POLDEM==1
gen WeakDem = 0 if (POLAFF==1 | POLAFF==2 | POLAFF==3)
replace WeakDem = 1 if POLDEM==5

* Define ranges for inflation expectations, PX1
gen r5_PX1 = 1 if (PX1>=-5 & PX1<=5)
gen r10_PX1 = 1 if (PX1>=-10 & PX1<=10)
gen r20_PX1 = 1 if (PX1>=-20 & PX1<=20)

* Define ranges for inflation expectations, PX5
gen r5_PX5 = 1 if (PX5>=-5 & PX5<=5)
gen r10_PX5 = 1 if (PX5>=-10 & PX5<=10)
gen r20_PX5 = 1 if (PX5>=-20 & PX5<=20)

* ------------------------------------------------------------------------------
* Surveys with political data
* ------------------------------------------------------------------------------

local survey ///
200609 200610 200611 ///
200803 200804 200805 200806 200809 200810 200811 200812 ///
200901 200902 200903 200904 200905 200906 ///
201003 201004 201005 201009 201010 201011 ///
201204 201205 201209 201210 201211 ///
201406 ///
201506 ///
201606 201607 201608 201609 201610 ///
201702 201703 201704 201705 ///

* ------------------------------------------------------------------------------
* Covariates
* ------------------------------------------------------------------------------

* Age squared
gen AGE_sq = AGE^2

* Covariates
local covariates i.REGION i.SEX AGE AGE_sq i.ECLGRD i.MARRY i.YTL5 i.RACE i.HOMEOWN

* ------------------------------------------------------------------------------
* Summary statistics
* ------------------------------------------------------------------------------

* Means, 1-yr
foreach date of local survey {

	quietly tabstat PX1 if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX1==1 & YYYYMM==`date', by(POLAFF) save
	if `date'==200609 {	
		matrix means_PX1 = (`date',r(Stat1),r(Stat2),r(Stat3)) 
	}
	else {
		matrix means_PX1 = means_PX1 \ (`date',r(Stat1),r(Stat2),r(Stat3))
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Means_1yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "Republican"
putexcel C1 = "Democrat"
putexcel D1 = "Independent"
putexcel A2 = matrix(means_PX1)

* Means, 5-yr
foreach date of local survey {

	quietly tabstat PX5 if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX5==1 & YYYYMM==`date', by(POLAFF) save
	if `date'==200609 {	
		matrix means_PX5 = (`date',r(Stat1),r(Stat2),r(Stat3)) 
	}
	else {
		matrix means_PX5 = means_PX5 \ (`date',r(Stat1),r(Stat2),r(Stat3))
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Means_5yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "Republican"
putexcel C1 = "Democrat"
putexcel D1 = "Independent"
putexcel A2 = matrix(means_PX5)

* Medians, 1-yr
foreach date of local survey {

	quietly iquantile PX1 if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX1==1 & YYYYMM==`date', by(POLAFF)
	if `date'==200609 {	
		matrix medians_PX1 = (`date',r(PX1_50_1),r(PX1_50_2),r(PX1_50_3)) 
	}
	else {
		matrix medians_PX1 = medians_PX1 \ (`date',r(PX1_50_1),r(PX1_50_2),r(PX1_50_3)) 
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Medians_1yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "Republican"
putexcel C1 = "Democrat"
putexcel D1 = "Independent"
putexcel A2 = matrix(medians_PX1)

* Medians, 5-yr
foreach date of local survey {

	quietly iquantile PX5 if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX5==1 & YYYYMM==`date', by(POLAFF)
	if `date'==200609 {	
		matrix medians_PX5 = (`date',r(PX5_50_1),r(PX5_50_2),r(PX5_50_3)) 
	}
	else {
		matrix medians_PX5 = medians_PX5 \ (`date',r(PX5_50_1),r(PX5_50_2),r(PX5_50_3)) 
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Medians_5yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "Republican"
putexcel C1 = "Democrat"
putexcel D1 = "Independent"
putexcel A2 = matrix(medians_PX5)

* Interest rate for borrowing
foreach date of local survey {

	quietly tabstat RATEX if (POLAFF==1 | POLAFF==2 | POLAFF==3) & YYYYMM==`date', by(POLAFF) save
	if `date'==200609 {	
		matrix means_RATEX = (`date',r(Stat1),r(Stat2),r(Stat3)) 
	}
	else {
		matrix means_RATEX = means_RATEX \ (`date',r(Stat1),r(Stat2),r(Stat3))
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("RATEX", replace) modify
putexcel A1 = "date"
putexcel B1 = "Republican"
putexcel C1 = "Democrat"
putexcel D1 = "Independent"
putexcel A2 = matrix(means_RATEX)

* ------------------------------------------------------------------------------
* Regression, by survey month
* ------------------------------------------------------------------------------

* Regression, 1-yr
foreach date of local survey {

	quietly reg PX1 `covariates' Republican Democrat if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX1==1 & YYYYMM==`date', r
	quietly lincom Democrat - Republican
	if `date'==200609 {	
		matrix reg_PX1 = (`date',r(estimate),r(se))
	}
	else {
		matrix reg_PX1 = reg_PX1 \ (`date',r(estimate),r(se))
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Regression_1yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "D minus R"
putexcel C1 = "se"
putexcel A2 = matrix(reg_PX1)

* Regression, 5-yr
foreach date of local survey {

	quietly reg PX5 `covariates' Republican Democrat if (POLAFF==1 | POLAFF==2 | POLAFF==3) & r20_PX5==1 & YYYYMM==`date', r
	quietly lincom Democrat - Republican
	if `date'==200609 {	
		matrix reg_PX5 = (`date',r(estimate),r(se))
	}
	else {
		matrix reg_PX5 = reg_PX5 \ (`date',r(estimate),r(se))
	}
}
putexcel set "${mystart}/Dropbox/Inflation Expectations/Michigan SCA/Output/CrossSection.xlsx", sheet("Regression_5yr", replace) modify
putexcel A1 = "date"
putexcel B1 = "D minus R"
putexcel C1 = "se"
putexcel A2 = matrix(reg_PX5)
