* ------------------------------------------------------------------------------
* Analysis file: Michigan SCA, panel data
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Load data
do "${mystart}/Inflation Expectations/Michigan SCA/Code/Load.do"

* Match re-interviewed cases
do "${mystart}/Inflation Expectations/Michigan SCA/Code/Match.do"

* Directory to save output
cd "${mystart}/Inflation Expectations/Michigan SCA/Output"

* ------------------------------------------------------------------------------
* Construct main variables
* ------------------------------------------------------------------------------

* Survey month, first interview
gen month = YYYYMM_int1 - YYYY_int1*100

* Check stability of political affiliation
tab POLAFF_int1 POLAFF_int2 if !missing(POLAFF_int1) & !missing(POLAFF_int2) & YYYY_int1>=2006, row

* Indicator for stable partisanship
gen stable = 1 if (POLAFF_int1==1 & POLAFF_int2==1) | (POLAFF_int1==2 & POLAFF_int2==2) | (POLAFF_int1==3 & POLAFF_int2==3)

* Partisanship, based on first interview
gen Republican = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace Republican = 1 if POLAFF_int1==1
gen Democrat = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace Democrat = 1 if POLAFF_int1==2
gen Independent = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace Independent = 1 if POLAFF_int1==3

* Partisanship by strength, based on first interview
gen StrongRep = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace StrongRep = 1 if POLREP_int1==1
gen WeakRep = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace WeakRep = 1 if POLREP_int1==5
gen StrongDem = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace StrongDem = 1 if POLDEM_int1==1
gen WeakDem = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3)
replace WeakDem = 1 if POLDEM_int1==5

* Define samples
gen sample2006 = 1 if (YYYYMM_int1>=200606 &  YYYYMM_int1<=200610)
gen sample2008 = 1 if (YYYYMM_int1>=200806 &  YYYYMM_int1<=200810)
gen sample2010 = 1 if (YYYYMM_int1>=201006 &  YYYYMM_int1<=201010)
gen sample2012 = 1 if (YYYYMM_int1>=201206 &  YYYYMM_int1<=201210)
gen sample2016 = 1 if (YYYYMM_int1>=201606 &  YYYYMM_int1<=201610)

* Change in inflation expectations
gen dPX1 = PX1_int2 - PX1_int1
gen dPX5 = PX5_int2 - PX5_int1

* Define ranges for inflation expectations, PX1
gen r5_PX1 = 1 if (PX1_int1>=-5 & PX1_int1<=5) & (PX1_int2>=-5 & PX1_int2<=5)
gen r10_PX1 = 1 if (PX1_int1>=-10 & PX1_int1<=10) & (PX1_int2>=-10 & PX1_int2<=10)
gen r20_PX1 = 1 if (PX1_int1>=-20 & PX1_int1<=20) & (PX1_int2>=-20 & PX1_int2<=20)

* Define ranges for inflation expectations, PX5
gen r5_PX5 = 1 if (PX5_int1>=-5 & PX5_int1<=5) & (PX5_int2>=-5 & PX5_int2<=5)
gen r10_PX5 = 1 if (PX5_int1>=-10 & PX5_int1<=10) & (PX5_int2>=-10 & PX5_int2<=10)
gen r20_PX5 = 1 if (PX5_int1>=-20 & PX5_int1<=20) & (PX5_int2>=-20 & PX5_int2<=20)

* ------------------------------------------------------------------------------
* Covariates
* ------------------------------------------------------------------------------

* Change in income expectations
gen dINEX = INEX_int2 - INEX_int1

* Change in gas price expectations
gen dGAS1 = GAS1PX2_int2 - GAS1PX2_int1
gen dGAS5 = GASPX2_int2 - GASPX2_int1

* Stock price expectations
gen dPSTK = PSTK_int2 - PSTK_int1

* Home price expectations
gen dHOMPX1 = HOMPX1_int2 - HOMPX1_int1
gen dHOMPX5 = HOMPX5_int2 - HOMPX5_int1

* Personal financial situation
gen dPEXP = 1 if (PEXP_int1==1 & PEXP_int2==3) | (PEXP_int1==1 & PEXP_int2==5) | (PEXP_int1==3 & PEXP_int2==5)
replace dPEXP = 2 if (PEXP_int1==1 & PEXP_int2==1) | (PEXP_int1==3 & PEXP_int2==3) | (PEXP_int1==5 & PEXP_int2==5)
replace dPEXP = 3 if (PEXP_int1==5 & PEXP_int2==3) | (PEXP_int1==5 & PEXP_int2==1) | (PEXP_int1==3 & PEXP_int2==1)
label define dPEXP 1 "Worse" 2 "No change" 3 "Better"
label values dPEXP dPEXP

* Unemployment expectations
gen dUNEMP = 1 if (UNEMP_int1==1 & UNEMP_int2==3) | (UNEMP_int1==1 & UNEMP_int2==5) | (UNEMP_int1==3 & UNEMP_int2==5)
replace dUNEMP = 2 if (UNEMP_int1==1 & UNEMP_int2==1) | (UNEMP_int1==3 & UNEMP_int2==3) | (UNEMP_int1==5 & UNEMP_int2==5)
replace dUNEMP = 3 if (UNEMP_int1==5 & UNEMP_int2==3) | (UNEMP_int1==5 & UNEMP_int2==1) | (UNEMP_int1==3 & UNEMP_int2==1)
label define dUNEMP 1 "Lower" 2 "No change" 3 "Higher"
label values dUNEMP dUNEMP

* Interest rate expectations
gen dRATEX = 1 if (RATEX_int1==1 & RATEX_int2==3) | (RATEX_int1==1 & RATEX_int2==5) | (RATEX_int1==3 & RATEX_int2==5)
replace dRATEX = 2 if (RATEX_int1==1 & RATEX_int2==1) | (RATEX_int1==3 & RATEX_int2==3) | (RATEX_int1==5 & RATEX_int2==5)
replace dRATEX = 3 if (RATEX_int1==5 & RATEX_int2==3) | (RATEX_int1==5 & RATEX_int2==1) | (RATEX_int1==3 & RATEX_int2==1)
label define dRATEX 1 "Lower" 2 "No change" 3 "Higher"
label values dRATEX dRATEX

* Change in business conditions over next year
gen dBEXP = 1 if (BEXP_int1==1 & BEXP_int2==3) | (BEXP_int1==1 & BEXP_int2==5) | (BEXP_int1==3 & BEXP_int2==5)
replace dBEXP = 2 if (BEXP_int1==1 & BEXP_int2==1) | (BEXP_int1==3 & BEXP_int2==3) | (BEXP_int1==5 & BEXP_int2==5)
replace dBEXP = 3 if (BEXP_int1==5 & BEXP_int2==3) | (BEXP_int1==5 & BEXP_int2==1) | (BEXP_int1==3 & BEXP_int2==1)
label define dBEXP 1 "Lower" 2 "No change" 3 "Higher"
label values dBEXP dBEXP

* Buying conditions, durables
gen dDUR = 1 if (DUR_int1==1 & DUR_int2==3) | (DUR_int1==1 & DUR_int2==5) | (DUR_int1==3 & DUR_int2==5)
replace dDUR = 2 if (DUR_int1==1 & DUR_int2==1) | (DUR_int1==3 & DUR_int2==3) | (DUR_int1==5 & DUR_int2==5)
replace dDUR = 3 if (DUR_int1==5 & DUR_int2==3) | (DUR_int1==5 & DUR_int2==1) | (DUR_int1==3 & DUR_int2==1)
label define dDUR 1 "Lower" 2 "No change" 3 "Higher"
label values dDUR dDUR

* Buying conditions, cars
gen dCAR = 1 if (CAR_int1==1 & CAR_int2==3) | (CAR_int1==1 & CAR_int2==5) | (CAR_int1==3 & CAR_int2==5)
replace dCAR = 2 if (CAR_int1==1 & CAR_int2==1) | (CAR_int1==3 & CAR_int2==3) | (CAR_int1==5 & CAR_int2==5)
replace dCAR = 3 if (CAR_int1==5 & CAR_int2==3) | (CAR_int1==5 & CAR_int2==1) | (CAR_int1==3 & CAR_int2==1)
label define dCAR 1 "Lower" 2 "No change" 3 "Higher"
label values dCAR dCAR

* Age squared
gen AGE_int1_sq = AGE_int1^2

* Categorical age variables
gen AGE_cat=1 if (AGE_int1>=40 & AGE_int1<=60)
replace AGE_cat=2 if AGE_int1<40
replace AGE_cat=3 if AGE_int1>60
label define AGE_cat 1 "Age 40 to 60" 2 "Age < 40" 3 "Age >60"
label values AGE_cat AGE_cat

* Indicator for partisan ID matching party of incoming President (2008 & 2012 elections)
gen support = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3) & (sample2008==1 | sample2016==1)
replace support = 1 if (sample2008==1 & POLAFF_int1==2) | (sample2016==1 & POLAFF_int1==1)
replace support = -1 if (sample2008==1 & POLAFF_int1==1) | (sample2016==1 & POLAFF_int1==2)

gen support_strong = 0 if (POLAFF_int1==1 | POLAFF_int1==2 | POLAFF_int1==3) & (sample2008==1 | sample2016==1)
replace support_strong = 1 if (sample2008==1 & StrongDem==1) | (sample2016==1 & StrongRep==1)
replace support_strong = -1 if (sample2008==1 & StrongRep==1) | (sample2016==1 & StrongDem==1)

* Covariates
local covariates i.REGION_int1 i.SEX_int1 AGE_int1 AGE_int1_sq i.ECLGRD_int1 i.MARRY_int1 i.YTL5_int1 i.RACE_int1 i.HOMEOWN_int1

* ------------------------------------------------------------------------------
* Regressions by election
* ------------------------------------------------------------------------------

local elections 2006 2008 2010 2012 2016
local range_px1 r20_PX1
local threshold_px1 20
local range_px5 r20_PX5
local threshold_px5 20

foreach electionYear of local elections { 

	* 1-yr expectations
	reg dPX1 Republican Democrat i.month if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, replace ctitle(OLS, dPX1) keep(Republican Democrat) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 1-yr expectations, with controls
	reg dPX1 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX1) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 1-yr expectations, by party strength
	reg dPX1 StrongRep WeakRep WeakDem StrongDem i.month if sample`electionYear'==1 & `range_px1'==1, r
	test StrongRep == StrongDem
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX1) keep(StrongRep WeakRep WeakDem StrongDem) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px1') addstat(p-value: StrongRep==StrongDem, r(p)) adec(2)

	* 1-yr expectations, by party strength, with controls
	reg dPX1 StrongRep WeakRep WeakDem StrongDem i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test StrongRep == StrongDem
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX1) keep(StrongRep WeakRep WeakDem StrongDem) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: StrongRep==StrongDem, r(p)) adec(2)

	* 5-yr expectations
	reg dPX5 Republican Democrat i.month if sample`electionYear'==1 & `range_px5'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX5) keep(Republican Democrat) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px5') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr expectations, with controls
	reg dPX5 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px5'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX5) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px5') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr expectations, by party strength
	reg dPX5 StrongRep WeakRep WeakDem StrongDem i.month if sample`electionYear'==1 & `range_px5'==1, r
	test StrongRep == StrongDem
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX5) keep(StrongRep WeakRep WeakDem StrongDem) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px5') addstat(p-value: StrongRep==StrongDem, r(p)) adec(2)

	* 5-yr expectations, by party strength, with controls
	reg dPX5 StrongRep WeakRep WeakDem StrongDem i.month `covariates' if sample`electionYear'==1 & `range_px5'==1, r
	test StrongRep == StrongDem
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX5) keep(StrongRep WeakRep WeakDem StrongDem) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px5') addstat(p-value: StrongRep==StrongDem, r(p)) adec(2)	
	
	* Unemployment rate expectations, with controls
	ologit dUNEMP Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, or
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dUNEMP) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform

	* Interest rate expectations, with controls
	ologit dRATEX Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, or
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dRATEX) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform
		
	* Income growth expectations, with controls	
	reg dINEX Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dINEX) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* Personal financial situation, with controls
	ologit dPEXP Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, or
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dPEXP) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform
		
	* 1-yr gas price expectations, with controls	
	reg dGAS1 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dGAS1) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr gas price expectations, with controls	
	reg dGAS5 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dGAS5) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* Stock price expectations, with controls
	reg dPSTK Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPSTK) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* Change in business conditions over next year, with controls
	ologit dBEXP Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dBEXP) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform
	
	* Buying conditions for durables, with controls
	ologit dDUR Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, or
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dDUR) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform
	
	* Buying conditions for cars, with controls
	ologit dCAR Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, or
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(ologit, dCAR) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform

	* 1-yr expectations, with standard control and gas price control
	reg dPX1 Republican Democrat i.month `covariates' dGAS1 if sample`electionYear'==1 & `range_px1'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX1) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes & dGAS1, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr expectations, with standard control and gas price control
	reg dPX5 Republican Democrat i.month `covariates' dGAS5 if sample`electionYear'==1 & `range_px5'==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'.xls, append ctitle(OLS, dPX5) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes & dGAS5, Exclude, |pie|>`threshold_px5') addstat(p-value: Republican==Democrat, r(p)) adec(2)

}
/*
* ------------------------------------------------------------------------------
* Match cases with same partisanship in both interviews 
* ------------------------------------------------------------------------------

local elections 2008 2016
local range_px1 r20_PX1
local threshold_px1 20
local range_px5 r20_PX5
local threshold_px5 20

foreach electionYear of local elections { 

	* 1-yr expectations
	reg dPX1 Republican Democrat i.month if sample`electionYear'==1 & `range_px1'==1 & stable==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'_stable.xls, replace ctitle(OLS, dPX1) keep(Republican Democrat) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 1-yr expectations, with controls
	reg dPX1 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px1'==1 & stable==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'_stable.xls, append ctitle(OLS, dPX1) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr expectations
	reg dPX5 Republican Democrat i.month if sample`electionYear'==1 & `range_px5'==1 & stable==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'_stable.xls, append ctitle(OLS, dPX5) keep(Republican Democrat) nocons dec(3) addtext(Controls, No, Exclude, |pie|>`threshold_px5') addstat(p-value: Republican==Democrat, r(p)) adec(2)

	* 5-yr expectations, with controls
	reg dPX5 Republican Democrat i.month `covariates' if sample`electionYear'==1 & `range_px5'==1 & stable==1, r
	test Republican == Democrat
	outreg2 using Output_`electionYear'_stable.xls, append ctitle(OLS, dPX5) keep(Republican Democrat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px5') addstat(p-value: Republican==Democrat, r(p)) adec(2)
	
}

* ------------------------------------------------------------------------------
* Heterogeneity
* ------------------------------------------------------------------------------

* Age
reg dPX1 i.month `covariates' c.support##AGE_cat if `range_px1'==1, r
outreg2 using Heterogeneity.xls, replace ctitle(OLS, dPX1) keep(c.support##AGE_cat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Gender
reg dPX1 i.month `covariates' c.support##SEX_int1 if `range_px1'==1, r
outreg2 using Heterogeneity.xls, append ctitle(OLS, dPX1) keep(c.support##SEX_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* College graduate
reg dPX1 i.month `covariates' c.support##ECLGRD_int1 if `range_px1'==1, r
outreg2 using Heterogeneity.xls, append ctitle(OLS, dPX1) keep(c.support##ECLGRD_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Income quartiles
reg dPX1 i.month `covariates' c.support##YTL4_int1 if `range_px1'==1, r
outreg2 using Heterogeneity.xls, append ctitle(OLS, dPX1) keep(c.support##YTL4_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Race
reg dPX1 i.month `covariates' c.support##RACE_int1 if `range_px1'==1, r
outreg2 using Heterogeneity.xls, append ctitle(OLS, dPX1) keep(c.support##RACE_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Home ownership
reg dPX1 i.month `covariates' c.support##HOMEOWN_int1 if `range_px1'==1, r
outreg2 using Heterogeneity.xls, append ctitle(OLS, dPX1) keep(c.support##HOMEOWN_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* ------------------------------------------------------------------------------
* Heterogeneity for just strong supporters
* ------------------------------------------------------------------------------

* Age
reg dPX1 i.month `covariates' c.support_strong##AGE_cat if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, replace ctitle(OLS, dPX1) keep(c.support_strong##AGE_cat) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Gender
reg dPX1 i.month `covariates' c.support_strong##SEX_int1 if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, append ctitle(OLS, dPX1) keep(c.support_strong##SEX_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* College graduate
reg dPX1 i.month `covariates' c.support_strong##ECLGRD_int1 if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, append ctitle(OLS, dPX1) keep(c.support_strong##ECLGRD_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Income quartiles
reg dPX1 i.month `covariates' c.support_strong##YTL4_int1 if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, append ctitle(OLS, dPX1) keep(c.support_strong##YTL4_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Race
reg dPX1 i.month `covariates' c.support_strong##RACE_int1 if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, append ctitle(OLS, dPX1) keep(c.support_strong##RACE_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* Home ownership
reg dPX1 i.month `covariates' c.support_strong##HOMEOWN_int1 if `range_px1'==1, r
outreg2 using Heterogeneity_strong.xls, append ctitle(OLS, dPX1) keep(c.support_strong##HOMEOWN_int1) nocons dec(3) addtext(Controls, Yes, Exclude, |pie|>`threshold_px1')

* ------------------------------------------------------------------------------
* News heard about prices
* ------------------------------------------------------------------------------

* Heard news about lower prices
gen NEWS_lowerPrices_int1 = 0
replace NEWS_lowerPrices_int1 = 1 if (NEWS1_int1==31 | NEWS2_int1==31)
gen NEWS_lowerPrices_int2 = 0
replace NEWS_lowerPrices_int2 = 1 if (NEWS1_int2==31 | NEWS2_int2==31)

* Heard news about higher prices
gen NEWS_higherPrices_int1 = 0
replace NEWS_higherPrices_int1 = 1 if (NEWS1_int1==72 | NEWS1_int1==72)
gen NEWS_higherPrices_int2 = 0
replace NEWS_higherPrices_int2 = 1 if (NEWS1_int2==72 | NEWS1_int2==72)

* Republicans
tab NEWS_lowerPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int1==1, cell
tab NEWS_higherPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int1==1, cell

* Democrats
tab NEWS_lowerPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int2==3, cell
tab NEWS_higherPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int1==3, cell

* Independents
tab NEWS_lowerPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int2==2, cell
tab NEWS_higherPrices_int1 NEWS_lowerPrices_int2 if sample2016==1 & POLAFF_int1==2, cell

* ------------------------------------------------------------------------------
* Tabulate political affiliation by strength
* ------------------------------------------------------------------------------

gen POLstrength = . 
replace POLstrength = 1 if StrongRep==1
replace POLstrength = 2 if WeakRep==1
replace POLstrength = 3 if Independent==1
replace POLstrength = 4 if WeakDem==1
replace POLstrength = 5 if StrongDem==1

label variable POLstrength "Political affiliation by strength"
label define POLstrength_name 1 "Strong Republican" 2 "Weak Republican" 3 "Independent" 4 "Weak Democrat" 5 "Strong Democrat"
label values POLstrength POLstrength_name

local electionYear 2016
local range_px1 r20_PX1
local covariates i.REGION_int1 i.SEX_int1 AGE_int1 AGE_int1_sq i.ECLGRD_int1 i.MARRY_int1 i.YTL5_int1 i.RACE_int1 i.HOMEOWN_int1

qui reg dPX1 StrongRep WeakRep WeakDem StrongDem i.month `covariates' if sample`electionYear'==1 & `range_px1'==1, r
tab POLstrength if e(sample)==1

tab POLstrength if `range_px1'==1 & !missing(dPX1) & (sample2008==1 | sample2016==1)

*/