* ------------------------------------------------------------------------------
* Match re-interviewed cases in Michigan SCA
* ------------------------------------------------------------------------------

set more off

* Indicator for first and second interview
gen current = string(YYYYMM) + "_" + string(ID) 
gen previous = string(DATEPR) + "_" + string(IDPREV) if !missing(DATEPR) & !missing(IDPREV)

* Identify re-interviewed cases by first interview date and ID
gen match = current
replace match = previous if !missing(previous)

* Group individuals
egen strata = group(match)
sort strata YYYYMM ID 
by strata : gen n = _n
by strata : gen N = _N
order strata n N, first

* Indicator for interview number
gen interview = "_int1" if n==1
replace interview = "_int2" if n==2

* Two cases recorded as matched to same previous interview
tab N
drop if N>2

* Drop variable not needed in wide form
drop n current previous match IDPREV DATEPR

local variables ///
ID        EHSGRD    YTL90     RACE      BUS5      INEXQ2    CARRN1    HOMPX5Q2  HTL10     POLAFF ///
YYYYMM    ECLGRD    INVEST    PAGO      GOVT      INEX      CARRN2    HOMPX5    HTL90     POLREP ///
YYYYQ     BIRTHM    INVAMT    PAGOR1    UNEMP     HOM       GASPX1    PJOB      HTL50     POLDEM ///
YYYY      BIRTHY    INVQFM    PAGOR2    RATEX     HOMRN1    GASPX2    PSSA      HTL5      POLCRD ///
REGION    MARRY     VEHOWN    PAGO5     PX1Q1     HOMRN2    GAS5      PINC      HTL4 ///
N         INCOME    VEHNUM    PEXP      PX1Q2     SHOM      GAS1PX1   PCRY      HTL3 ///
          INCQFM    HOMEOWN   PEXP5     PX1       SHOMRN1   GAS1PX2   PINC2     STL10 ///
WT        YTL50     HOMEVAL   BUS12     PX5Q1     SHOMRN2   GAS1      PSTK      STL90 ///
SEX       YTL3      HOMEAMT   BAGO      PX5Q2     DUR       HOMPX1Q1  ICS       STL50 ///
AGE       YTL4      HOMEQFM   NEWS1     PX5       DURRN1    HOMPX1Q2  ICC       STL5 ///
EDUC      YTL5      NUMKID    NEWS2     RINC      DURRN2    HOMPX1    ICE       STL4 ///
EGRADE    YTL10     NUMADT    BEXP      INEXQ1    CAR       HOMPX5Q1  REFCON    STL3

* Reshape wide
reshape wide `variables', i(strata) j(interview) string

* Indicator for re-interviewed cases
rename N_int1 N
drop N_int2 strata
order N, last

* Re-label variables
do "${mystart}/Inflation Expectations/Michigan SCA/Code/Labels.do"

