* ------------------------------------------------------------------------------
* Analysis of change in prices expectations: 2012 US Presidential Election
* ------------------------------------------------------------------------------

cls
capture restore
clear
set more off

* Load merged pre- and post-election survey data
run "${mystart}Inflation Expectations/RAND/2012 election/Code/Setup.do"

* Load merged pre- and post-election survey data
use "${mystart}Inflation Expectations/RAND/2012 election/Code/merged.dta", clear 
erase "${mystart}Inflation Expectations/RAND/2012 election/Code/merged.dta"

* Directory to save output
cd  "${mystart}Inflation Expectations/RAND/2012 election/Output"

* ------------------------------------------------------------------------------
* Construct variables
* ------------------------------------------------------------------------------

* Create dummy variables by party ID
gen republican = 0 if !missing(party)
replace republican = 1 if party==3
gen democrat = 0 if !missing(party)
replace democrat = 1 if party==2

* Create dummy variables by party strength ID
gen strongRep = 0 if !missing(partystrength)
replace strongRep = 1 if partystrength==5
gen weakRep = 0 if !missing(partystrength)
replace weakRep = 1 if partystrength==4
gen weakDem = 0 if !missing(partystrength)
replace weakDem = 1 if partystrength==3
gen strongDem = 0 if !missing(partystrength)
replace strongDem = 1 if partystrength==2

* Expected winner, Republicans
gen republican_romney = 0 if !missing(party) & !missing(ewin_romney)
replace republican_romney = 1 if party==3 & ewin_romney==1

* Expected winner, by strength of Republican affiliation
gen strongRep_romney = 0 if !missing(partystrength) & !missing(ewin_romney)
replace strongRep_romney = 1 if strongRep==1 & ewin_romney==1
gen weakRep_romney = 0 if !missing(partystrength) & !missing(ewin_romney)
replace weakRep_romney = 1 if weakRep==1 & ewin_romney==1

* Change in personal finance expectations
gen dpersonalFinance = 1 if (personalFinance_pre==1 & personalFinance_post==2) | (personalFinance_pre==1 & personalFinance_post==3) | (personalFinance_pre==2 & personalFinance_post==3)
replace dpersonalFinance = 2 if (personalFinance_pre==1 & personalFinance_post==1) | (personalFinance_pre==2 & personalFinance_post==2) | (personalFinance_pre==3 & personalFinance_post==3)
replace dpersonalFinance = 3 if (personalFinance_pre==3 & personalFinance_post==2) | (personalFinance_pre==3 & personalFinance_post==1) | (personalFinance_pre==2 & personalFinance_post==1)
label define dpersonalFinance 1 "Worse" 2 "No change" 3 "Better"
label values dpersonalFinance dpersonalFinance

* Change in unemployment expectations
gen dunemployment = 1 if (unemployment_pre==1 & unemployment_post==2) | (unemployment_pre==1 & unemployment_post==3) | (unemployment_pre==2 & unemployment_post==3)
replace dunemployment = 2 if (unemployment_pre==1 & unemployment_post==1) | (unemployment_pre==2 & unemployment_post==2) | (unemployment_pre==3 & unemployment_post==3)
replace dunemployment = 3 if (unemployment_pre==3 & unemployment_post==2) | (unemployment_pre==3 & unemployment_post==1) | (unemployment_pre==2 & unemployment_post==1)
label define dunemployment 1 "Lower" 2 "No change" 3 "Higher"
label values dunemployment dunemployment

* Change in interest rate expectations
gen dinterest = 1 if (interest_pre==1 & interest_post==2) | (interest_pre==1 & interest_post==3) | (interest_pre==2 & interest_post==3)
replace dinterest = 2 if (interest_pre==1 & interest_post==1) | (interest_pre==2 & interest_post==2) | (interest_pre==3 & interest_post==3)
replace dinterest = 3 if (interest_pre==3 & interest_post==2) | (interest_pre==3 & interest_post==1) | (interest_pre==2 & interest_post==1)
label define dinterest 1 "Lower" 2 "No change" 3 "Higher"
label values dinterest dinterest

* Define ranges for inflation expectations, 1-yr
gen r5_px1 = 1 if (prices_pre>=-5 & prices_pre<=5) & (prices_post>=-5 & prices_post<=5)
gen r10_px1 = 1 if (prices_pre>=-10 & prices_pre<=10) & (prices_post>=-10 & prices_post<=10)
gen r20_px1 = 1 if (prices_pre>=-20 & prices_pre<=20) & (prices_post>=-20 & prices_post<=20)

* Sample period
gen samplePost_November = 1 if ms311_tsend_my=="11/2012"
gen samplePost_8days = 1 if (ms311_tsend_dmy=="07/11/2012" | ms311_tsend_dmy=="08/11/2012" | ms311_tsend_dmy=="09/11/2012" | ms311_tsend_dmy=="10/11/2012" | ///
							 ms311_tsend_dmy=="11/11/2012" | ms311_tsend_dmy=="12/11/2012" | ms311_tsend_dmy=="13/11/2012" | ms311_tsend_dmy=="14/11/2012")

* Covariates
local covariates "foreignborn female age age_sq hispanic i.ethnicity married i.education i.familyincome i.jobstatus i.hhsize"

* ------------------------------------------------------------------------------
* Cross-tab analysis
* ------------------------------------------------------------------------------

* Voted by party affiliation
table partystrength, c(mean voted sd voted n voted)

* Change in mean inflation expectations: by party identification and expected winner
table partystrength ewin_romney, c(mean dprices sd dprices n dprices)

* Interpolated change in median inflation expectations, by party affiliation and expected winner
iquantile dprices, by(party ewin_romney) p(50)

* Expected winner: by party
tab party if r20_px1==1, su(ewin_obama)
tab partystrength if r20_px1==1, su(ewin_obama)

* ------------------------------------------------------------------------------
* Plot CDF of price expectations by party, pre- and post-election
* ------------------------------------------------------------------------------

gen prices_pre_dem = prices_pre if party==2 & ewin_obama==1 & !missing(dprices)
gen prices_pre_gop = prices_pre if party==3 & ewin_obama==0 & !missing(dprices)
cumul prices_pre_dem if r20_px1==1, gen(cdf_pre_dem) equal
cumul prices_pre_gop if r20_px1==1, gen(cdf_pre_gop) equal

gen prices_post_dem = prices_post if party==2 & ewin_obama==1 & !missing(dprices)
gen prices_post_gop = prices_post if party==3 & ewin_obama==0 & !missing(dprices)
cumul prices_post_dem if r20_px1==1, gen(cdf_post_dem) equal
cumul prices_post_gop if r20_px1==1, gen(cdf_post_gop) equal

* Democrats pre/post (expecting Obama victory)
twoway (line cdf_pre_dem prices_pre_dem, sort lcolor(black) lpattern(dash)) (line cdf_post_dem prices_post_dem, sort lcolor(black)) if (prices_pre_dem>=-20 & prices_pre_dem<=20) & (prices_post_dem>=-20 & prices_post_dem<=20), xtitle("Expected change in prices over the next 12 months (per cent)") ytitle("Cumulative distribution") legend(lab(1 "pre-election") lab(2 "post-election") rows(1)) bgcolor(white) graphregion(fcolor(white)) plotregion(lstyle(solid) lcolor(black)) yscale(range(0 1)) ylabel(0(0.2)1) ytick(0(0.1)1)
graph export cdf_Democrats.pdf, replace

* Republicans pre/post (expecting Romney victory)
twoway (line cdf_pre_gop prices_pre_gop, sort lcolor(black) lpattern(dash)) (line cdf_post_gop prices_post_gop, sort lcolor(black)) if (prices_pre_gop>=-20 & prices_pre_gop<=20) & (prices_post_gop>=-20 & prices_post_gop<=20), xtitle("Expected change in prices over the next 12 months (per cent)") ytitle("Cumulative distribution") legend(lab(1 "pre-election") lab(2 "post-election") rows(1)) bgcolor(white) graphregion(fcolor(white)) plotregion(lstyle(solid) lcolor(black)) yscale(range(0 1)) ylabel(0(0.2)1) ytick(0(0.1)1)
graph export cdf_Republicans.pdf, replace

* Democrats vs. Republican pre-election (expecting own party victory)
twoway (line cdf_pre_dem prices_pre, sort lcolor(black) lpattern(dash)) (line cdf_pre_gop prices_pre, sort lcolor(black)) if (prices_pre>=-20 & prices_pre<=20), xtitle("Expected change in prices over the next 12 months (per cent)") ytitle("Cumulative distribution") legend(lab(1 "Democrats") lab(2 "Republicans") rows(1)) bgcolor(white) graphregion(fcolor(white)) plotregion(lstyle(solid) lcolor(black)) yscale(range(0 1)) ylabel(0(0.2)1) ytick(0(0.1)1)

* Democrats vs. Republican post-election (expecting own party victory)
twoway (line cdf_post_dem prices_post, sort lcolor(black) lpattern(dash)) (line cdf_post_gop prices_post, sort lcolor(black)) if (prices_post>=-20 & prices_post<=20), xtitle("Expected change in prices over the next 12 months (per cent)") ytitle("Cumulative distribution") legend(lab(1 "Democrats") lab(2 "Republicans") rows(1)) bgcolor(white) graphregion(fcolor(white)) plotregion(lstyle(solid) lcolor(black)) yscale(range(0 1)) ylabel(0(0.2)1) ytick(0(0.1)1)

* ------------------------------------------------------------------------------
* Regression analysis
* ------------------------------------------------------------------------------

local samplePeriod samplePost_8days
local range r20_px1
local threshold_px1 20

* By party
reg dprices i.ms303_tsend_day i.ms311_tsend_day democrat republican if `samplePeriod'==1 & `range'==1, r
test democrat==republican
outreg2 using Output.xls, replace ctitle(OLS, dprices) dec(3) keep(democrat republican) nocons addtext(Controls, No, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

* By party, with controls
reg dprices i.ms303_tsend_day i.ms311_tsend_day `covariates' democrat republican if `samplePeriod'==1 & `range'==1, r
test democrat==republican
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(democrat republican) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2)

* By party, expected winner
reg dprices i.ms303_tsend_day i.ms311_tsend_day democrat republican republican_romney if `samplePeriod'==1 & `range'==1, r
test democrat==republican_romney
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(democrat republican republican_romney) nocons addtext(Controls, No, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican(R-win)==Democrat, r(p)) adec(2)

* By party, expected winner, with controls
reg dprices i.ms303_tsend_day i.ms311_tsend_day `covariates' democrat republican republican_romney if `samplePeriod'==1 & `range'==1, r
test democrat==republican_romney
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(democrat republican republican_romney) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican(R-win)==Democrat, r(p)) adec(2)

* By party strength
reg dprices i.ms303_tsend_day i.ms311_tsend_day strongDem weakDem weakRep strongRep if `samplePeriod'==1 & `range'==1, r
test strongDem==strongRep
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(strongDem weakDem weakRep strongRep) nocons addtext(Controls, No, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Strong Rep==Strong Dem, r(p)) adec(2)

* By party strength, with controls
reg dprices i.ms303_tsend_day i.ms311_tsend_day `covariates' strongDem weakDem weakRep strongRep if `samplePeriod'==1 & `range'==1, r
test strongDem==strongRep
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(strongDem weakDem weakRep strongRep) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Strong Rep==Strong Dem, r(p)) adec(2)

* By party strength, expected winner
reg dprices i.ms303_tsend_day i.ms311_tsend_day strongDem weakDem weakRep weakRep_romney strongRep strongRep_romney if `samplePeriod'==1 & `range'==1, r
test strongDem==strongRep_romney
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(strongDem weakDem weakRep weakRep_romney strongRep strongRep_romney) nocons addtext(Controls, No, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Strong Rep (R-win)==Strong Dem, r(p)) adec(2)

* By party strength, expected winner, with controls
reg dprices i.ms303_tsend_day i.ms311_tsend_day `covariates' strongDem weakDem weakRep weakRep_romney strongRep strongRep_romney if `samplePeriod'==1 & `range'==1, r
test strongDem==strongRep_romney
outreg2 using Output.xls, append ctitle(OLS, dprices) dec(3) keep(strongDem weakDem weakRep weakRep_romney strongRep strongRep_romney) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Strong Rep (R-win)==Strong Dem, r(p)) adec(2)

* Change in personal finances, with controls
ologit dpersonalFinance i.ms303_tsend_day i.ms311_tsend_day `covariates' democrat republican if `samplePeriod'==1 & `range'==1, or
test democrat==republican
outreg2 using Output.xls, append ctitle(OLS, dfinances) dec(3) keep(democrat republican) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform

* Change in unemployment, with controls
ologit dunemployment i.ms303_tsend_day i.ms311_tsend_day `covariates' democrat republican if `samplePeriod'==1 & `range'==1, or
test democrat==republican
outreg2 using Output.xls, append ctitle(OLS, dunemp.) dec(3) keep(democrat republican) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform

* Change in interest rates, with controls
ologit dinterest i.ms303_tsend_day i.ms311_tsend_day `covariates' democrat republican if `samplePeriod'==1 & `range'==1, or
test democrat==republican
outreg2 using Output.xls, append ctitle(OLS, dinterest) dec(3) keep(democrat republican) nocons addtext(Controls, Yes, Sample, 8d pre/post, Exclude, |pie|>`threshold_px1') addstat(p-value: Republican==Democrat, r(p)) adec(2) eform

* ------------------------------------------------------------------------------
* Summary table
* ------------------------------------------------------------------------------

* Generate variables for summary table
gen college = 0 if !missing(education)
replace college = 1 if education>=4

gen familyincome_detailed = ms303_familyincome

gen white = 0 if !missing(ethnicity)
replace white = 1 if ethnicity==1 & hispanic==0

gen africanAmerican = 0 if !missing(ethnicity)
replace africanAmerican = 1 if ethnicity==2 & hispanic==0

local samplePeriod samplePost_8days
local range r20_px1
format college married female white africanAmerican hispanic %9.2f

tabstat familyincome_detailed age college married female white africanAmerican hispanic if `samplePeriod'==1 & `range'==1, by(party) stat(mean)
tabstat familyincome_detailed age college married female white africanAmerican hispanic if `samplePeriod'==1 & `range'==1, by(party) stat(median)
