* ------------------------------------------------------------------------------
* Setup data
* ------------------------------------------------------------------------------

cls
capture restore
clear
set more off

* ------------------------------------------------------------------------------
* Organise data for "ALP: Multiple Authors post-election follow-up" (ms311)
* ------------------------------------------------------------------------------

cd "${mystart}Inflation Expectations/RAND/ms311/STATA"
insheet using ALP_MS311.csv, clear

* Rename ID key
rename ms311_prim_key ID

* Date survey completed
drop if missing(ms311_tsend)
gen ms311_tsend_year = substr(ms311_tsend,1,4)
gen ms311_tsend_month = substr(ms311_tsend,6,2)
gen ms311_tsend_day = substr(ms311_tsend,9,2)
gen ms311_tsend_my = ms311_tsend_month + "/" + ms311_tsend_year
gen ms311_tsend_dmy = ms311_tsend_day + "/" + ms311_tsend_month + "/" + ms311_tsend_year
destring ms311_tsend_year, replace
destring ms311_tsend_month, replace
destring ms311_tsend_day, replace

* Create variable for expected change in prices
gen prices_post = ms311_q5b
replace prices_post = -ms311_q5c if missing(prices_post)
replace prices_post = 0 if ms311_q5a==2

* Create variable for expected change in personal financial situation next year
gen personalFinance_post = ms311_ee01
label define label_personalFinance_post 1 "Better" 2 "Same" 3 "Worse" 
label values personalFinance_post label_personalFinance_post

* Create variable for expected change in unemployment
gen unemployment_post = ms311_ee03
label define label_unemployment_post 1 "Up" 2 "Same" 3 "Down" 
label values unemployment_post label_unemployment_post

* Create variable for expected change in interest rates
gen interest_post = ms311_ee04
label define label_interest_post 1 "Up" 2 "Same" 3 "Down" 
label values interest_post label_interest_post

* Create indicator for voted
gen voted = 1 if ms311_dm_01==1
replace voted = 0 if ms311_dm_01==2

* Keep variables to be merged, save
keep ID prices_post interest_post voted ms311_tsend_my ms311_tsend_dmy ms311_tsend_year ms311_tsend_month ms311_tsend_day personalFinance_post unemployment_post interest_post
order ID ms311_tsend_my ms311_tsend_dmy prices_post interest_post voted
save "${mystart}Inflation Expectations/RAND/2012 election/Code/ms311_merge.dta", replace

* ------------------------------------------------------------------------------
* Organise data for "ALP: Kimball pre-election" (ms303)
* ------------------------------------------------------------------------------

cd "${mystart}Inflation Expectations/RAND/ms303/STATA"
insheet using ALP_MS303.csv, clear

* Date survey completed
drop if missing(ms303_tsend)
gen ms303_tsend_year = substr(ms303_tsend,1,4)
gen ms303_tsend_month = substr(ms303_tsend,6,2)
gen ms303_tsend_day = substr(ms303_tsend,9,2)
gen ms303_tsend_my = ms303_tsend_month + "/" + ms303_tsend_year
gen ms303_tsend_dmy = ms303_tsend_day + "/" + ms303_tsend_month + "/" + ms303_tsend_year
destring ms303_tsend_year, replace
destring ms303_tsend_month, replace
destring ms303_tsend_day, replace
drop if ms303_tsend_year>=2012 & ms303_tsend_month>=11 & ms303_tsend_day>=6

* Create variable for expected change in prices
gen prices_pre = ms303_ee_6a
replace prices_pre = -ms303_ee_6b if missing(prices_pre)
replace prices_pre = 0 if ms303_ee_5a==2

* Create variable for expected change in personal financial situation next year
gen personalFinance_pre = ms303_ee_1
label define label_personalFinance_pre 1 "Better" 2 "Same" 3 "Worse" 
label values personalFinance_pre label_personalFinance_pre

* Create variable for expected change in unemployment
gen unemployment_pre = ms303_ee_3
label define label_unemployment_pre 1 "Up" 2 "Same" 3 "Down" 
label values unemployment_pre label_unemployment_pre

* Create variable for expected change in interest rates
gen interest_pre = ms303_ee_4
label define label_interest_pre 1 "Up" 2 "Same" 3 "Down" 
label values interest_pre label_interest_pre

* Create indicator for expected Obama victory
gen ewin_obama = 1 if ms303_p002_m==2 | ms303_p002_o==1
replace ewin_obama = 0 if ms303_p002_m==1 | ms303_p002_o==2
format ewin_obama %4.2f

* Create indicator for expected Romney victory
gen ewin_romney = 1 if ewin_obama==0
replace ewin_romney = 0 if ewin_obama==1
format ewin_romney %4.2f

* Create partisanship affiliation variable
gen party = ms303_p001
recode party (1=3) (3=1)
recode party (4=.)
label define label_party 1 "Independent" 2 "Democrat" 3 "Republican"
label values party label_party

* Create partisanship affiliation variable: detailed
gen partystrength = 1 if ms303_p001==3
replace partystrength = 2 if ms303_p001==2 & ms303_p001d==1
replace partystrength = 3 if ms303_p001==2 & ms303_p001d==2
replace partystrength = 4 if ms303_p001==1 & ms303_p001r==2
replace partystrength = 5 if ms303_p001==1 & ms303_p001r==1
label define label_partystrength 1 "Independent" 2 "Strong Democrat" 3 "Weak Democrat" 4 "Weak Republican" 5 "Strong Republican"
label values partystrength label_partystrength

* Born in US
gen foreignborn = 1 if ms303_borninus==2
replace foreignborn = 0 if ms303_borninus==1

* Gender
gen female = 1 if ms303_gender==2
replace female = 0 if ms303_gender==1

* Age
gen age = ms303_calcage
gen age_sq = age^2

* Hispanic
gen hispanic = 1 if ms303_hispaniclatino==1
replace hispanic = 0 if ms303_hispaniclatino==2

* Ethnicity
gen ethnicity = 1 if ms303_ethnicity==1
replace ethnicity = 2 if ms303_ethnicity==2
replace ethnicity = 3 if (ms303_ethnicity==3 | ms303_ethnicity==4 | ms303_ethnicity==5)
label define label_ethnicity 1 "White" 2 "African American" 3 "Other"
label values ethnicity label_ethnicity

* Married
gen married = 1 if ms303_currentlivingsituation==1
replace married = 0 if (ms303_currentlivingsituation>=2 & ms303_currentlivingsituation<=5)

* Highest education
gen education = 1 if (ms303_highesteducation>=1 & ms303_highesteducation<=8)
replace education = 2 if ms303_highesteducation==9
replace education = 3 if ms303_highesteducation==10
replace education = 4 if (ms303_highesteducation==11 | ms303_highesteducation==12)
replace education = 5 if ms303_highesteducation==13
replace education = 6 if (ms303_highesteducation>=14 & ms303_highesteducation<=16)
label define label_education 1 "No high school diploma" 2 "High school" 3 "Some college" 4 "Associate degree" 5 "Bachelor's degree" 6 "Masters or higher"
label values education label_education

* Family income
gen familyincome = 1 if (ms303_familyincome>=1 & ms303_familyincome<=7)
replace familyincome = 2 if (ms303_familyincome>=8 & ms303_familyincome<=11)
replace familyincome = 3 if (ms303_familyincome>=12 & ms303_familyincome<=13)
replace familyincome = 4 if ms303_familyincome_part2==1
replace familyincome = 5 if ms303_familyincome_part2==2
replace familyincome = 6 if (ms303_familyincome_part2>=3 & ms303_familyincome_part2<=4)
label define label_familyincome 1 "0-25k" 2 "25-50k" 3 "50-75k" 4 "75-100k" 5 "100-125k" 6 ">125k"
label values familyincome label_familyincome

* Current job status
gen jobstatus = 1 if (ms303_currentjobstatuss1==1 | ms303_currentjobstatuss3==1)
replace jobstatus = 2 if ms303_currentjobstatuss2==2
replace jobstatus = 3 if (ms303_currentjobstatuss4==4 | ms303_currentjobstatuss5==5 | ms303_currentjobstatuss6==6 | ms303_currentjobstatuss7==7)
label define label_jobstatus 1 "Working" 2 "Unemployed" 3 "Disabled/Retired/Homemaker/other"
label values jobstatus label_jobstatus

* Number of household members
gen hhsize = 1 if ms303_householdmembers==0
replace hhsize = 2 if ms303_householdmembers==1
replace hhsize = 3 if (ms303_householdmembers>=2 & ms303_householdmembers<=10)
label define label_hhsize 1 "1" 2 "2" 3 ">2" 
label values hhsize label_hhsize

* ------------------------------------------------------------------------------
* Merge pre-election survey (ms303) and post-election survey (ms311)
* ------------------------------------------------------------------------------

* Combine and drop unmatched post-election data
rename ms303_prim_key ID
merge 1:1 ID using "${mystart}Inflation Expectations/RAND/2012 election/Code/ms311_merge.dta"
drop if _merge==2

* Change in inflation expectation
gen dprices = prices_post - prices_pre if _merge==3

* Characteristics of matched and unmatched data: inflation expectations
tabstat prices_pre if _merge!=2, by(_merge) stat(n median mean sd) format save

save "${mystart}Inflation Expectations/RAND/2012 election/Code/merged.dta", replace
erase "${mystart}Inflation Expectations/RAND/2012 election/Code/ms311_merge.dta"
