* ------------------------------------------------------------------------------
* Survey of Professional Forecasters, CPI
* ------------------------------------------------------------------------------

* Survey dates at: https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/survey-of-professional-forecasters/spf-release-dates.txt?la=en
* Q4 survey closes after 1992, 2000, 2008 elections; Q4 survey closes before 2016 election

cls
capture restore
set more off

* Directory to save output
cd "${mystart}/Inflation Expectations/SPF/Output"

* ------------------------------------------------------------------------------
* Load and organise data
* ------------------------------------------------------------------------------

* Load raw data
import excel using "${mystart}/Inflation Expectations/SPF/Data/micro2.xlsx", sheet("CPI") cellrange(A1:M1144) firstrow clear
drop INDUSTRY
save micro2.dta, replace
import excel using "${mystart}/Inflation Expectations/SPF/Data/micro3.xlsx", sheet("CPI") cellrange(A1:M1401) firstrow clear
drop INDUSTRY
save micro3.dta, replace
import excel using "${mystart}/Inflation Expectations/SPF/Data/micro4.xlsx", sheet("CPI") cellrange(A1:M1633) firstrow clear
drop INDUSTRY
save micro4.dta, replace
import excel using "${mystart}/Inflation Expectations/SPF/Data/micro5.xlsx", sheet("CPI") cellrange(A1:M1378) firstrow clear
drop INDUSTRY
save micro5.dta, replace

* Join data
use micro2.dta, clear
append using micro3.dta
append using micro4.dta
append using micro5.dta
save CPI.dta, replace

* Create date variable
gen DATE = yq(YEAR,QUARTER)
format DATE %tq
order DATE, first

* Format missing values
local series CPI1 CPI2 CPI3 CPI4 CPI5 CPI6 CPIA CPIB CPIC
foreach x of local series  {
	replace `x' = "." if `x'=="#N/A"
	destring `x', replace
}

* Declare panel data
sort ID DATE
xtset ID DATE

* Erase intermediate files 
erase micro2.dta
erase micro3.dta
erase micro4.dta
erase micro5.dta

* Inflation measure
gen pie = (1/4)*(CPI3+CPI4+CPI5+CPI6)

* Previous forecast
by ID: gen pie_L1 = L.pie
by ID: gen CPIB_L1 = L.CPIB

* Keep paired forcasts
keep if !missing(pie) & !missing(pie_L1)

* ------------------------------------------------------------------------------
* Forecast revisions
* ------------------------------------------------------------------------------

*Forecast revision, total
by ID: gen dpie = pie - pie_L1
by ID: gen dpie_abs = abs(dpie)

*All periods
su dpie_abs

* 1992 presidential election
su dpie_abs if DATE==tq(1992q4)

* 2000 presidential election
su dpie_abs if DATE==tq(2000q4)

* 2008 presidential election
su dpie_abs if DATE==tq(2008q4)

* 2016 presidential election
su dpie_abs if DATE==tq(2017q1)

* ------------------------------------------------------------------------------
* Revision in forecast ranks
* ------------------------------------------------------------------------------

* Note: treat pairs of forecasts as independent for calculation of standard errors; likely to overstate precision

* Average correlation: 1989q1-2018q1
scalar i = 0 
scalar sum = 0
scalar var = 0
forvalues t = `=q(1989q1)'/`=q(2018q1)' {
	scalar i = i + 1
	spearman pie pie_L1 if DATE==`t'
	scalar sum = sum + r(rho)
	scalar var = var + 1/(r(N)-3)
   }
scalar rho_avg = sum/i
scalar rho_avg_Fisher = 0.5*ln((1+rho_avg)/(1-rho_avg))
scalar var_avg = (1/i^2)*var

* 1992 presidential election
spearman CPIB CPIB_L1 if DATE==tq(1992q4)
scalar N = r(N)
scalar rho = r(rho)
scalar rho_Fisher = 0.5*ln((1+rho)/(1-rho))
scalar z_1992 = (rho_avg_Fisher - rho_Fisher)/sqrt((1/(N-3))+var_avg)
scalar p_1992 = 1 - normal(z_1992)
disp "1992 presidential election"
disp "z-stat: " z_1992 " p-value: " p_1992

* 2000 presidential election
spearman CPIB CPIB_L1 if DATE==tq(2000q4)
scalar N = r(N)
scalar rho = r(rho)
scalar rho_Fisher = 0.5*ln((1+rho)/(1-rho))
scalar z_2000 = (rho_avg_Fisher - rho_Fisher)/sqrt((1/(N-3))+var_avg)
scalar p_2000 = 1 - normal(z_2000)
disp "2000 presidential election"
disp "z-stat: " z_2000 " p-value: " p_2000

* 2008 presidential election
spearman CPIB CPIB_L1 if DATE==tq(2008q4)
scalar N = r(N)
scalar rho = r(rho)
scalar rho_Fisher = 0.5*ln((1+rho)/(1-rho))
scalar z_2008 = (rho_avg_Fisher - rho_Fisher)/sqrt((1/(N-3))+var_avg)
scalar p_2008 = 1 - normal(z_2008)
disp "2008 presidential election"
disp "z-stat: " z_2008 " p-value: " p_2008

* 2016 presidential election
spearman CPIA CPIB if DATE==tq(2017q1)
scalar N = r(N)
scalar rho = r(rho)
scalar rho_Fisher = 0.5*ln((1+rho)/(1-rho))
scalar z_2016 = (rho_avg_Fisher - rho_Fisher)/sqrt((1/(N-3))+var_avg)
scalar p_2016 = 1 - normal(z_2016)
disp "2016 presidential election"
disp "z-stat: " z_2016 " p-value: " p_2016


