* ------------------------------------------------------------------------------
* Australia: Inflation by party
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Directory to save output
global mystart `"C:\Users\z3504163"'
cd "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/Australia"

* Load data
import excel using "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/Australia/Inflation by party.xlsx", sheet("Data") cellrange(A9:E297) firstrow clear

* Construct quarterly date variable
gen year = year(date)
gen month = month(date)
gen quarter = 1 if month==3
replace quarter = 2 if month==6
replace quarter = 3 if month==9
replace quarter = 4 if month==12
gen date_q = yq(year,quarter)
format date_q %tq
order date_q
drop year month quarter date

* Declare time series
tsset date_q

* ------------------------------------------------------------------------------
* Construct data
* ------------------------------------------------------------------------------

* Inflation measures
gen dlGNED = 400*log(GNED/L.GNED)
gen dlCPI = 400*log(CPI/L.CPI)

* Party
gen ALP = 0
replace ALP = 1 if Party=="ALP"
gen LibNat = 0
replace LibNat = 1 if Party=="Lib/Nat"

local pi dlGNED dlCPI

* ------------------------------------------------------------------------------
* Regressions, full sample
* ------------------------------------------------------------------------------
* Clustered by prime ministerial term
foreach x of local pi{
reg `x' ALP LibNat if date_q>=tq(1946q3), nocons cluster(PM)
matrix `x'b=e(b)
matrix `x'ALPb=`x'b[1,1]
matrix `x'Libb=`x'b[1,2]
matrix `x'se=e(V)
matrix `x'ALPse=`x'se[1,1]^0.5
matrix `x'Libse=`x'se[2,2]^0.5
}

foreach x of local pi{
reg `x' ALP if date_q>=tq(1946q3), cluster(PM)
matrix `x'bdif=e(b)
matrix `x'ALPbdif=`x'bdif[1,1]
matrix `x'sedif=e(V)
matrix `x'ALPsedif=`x'sedif[1,1]^0.5
}

* Newey-West, 6 lags

foreach x of local pi{
newey `x' ALP LibNat if date_q>=tq(1946q3), nocons lag(6)
matrix `x'senw=e(V)
matrix `x'ALPsenw=`x'senw[1,1]^0.5
matrix `x'Libsenw=`x'senw[2,2]^0.5
}

foreach x of local pi{
newey `x' ALP if date_q>=tq(1946q3), lag(6)
matrix `x'bdifnw=e(b)
matrix `x'ALPbdifnw=`x'bdifnw[1,1]
matrix `x'sedifnw=e(V)
matrix `x'ALPsedifnw=`x'sedifnw[1,1]^0.5
}


* ------------------------------------------------------------------------------
* Regressions, expectations sample 
* ------------------------------------------------------------------------------

newey dlCPI ALP if date_q>=tq(1994q4), lag(6)

* Date the inflation targeting period starting in June 1993 (see https://www.rba.gov.au/speeches/1999/sp-ag-200499.html)

* Clustered by prime ministerial term
foreach x of local pi{
reg `x' ALP LibNat if date_q>=tq(1993q2), nocons cluster(PM)
matrix `x'bv=e(b)
matrix `x'ALPbv=`x'bv[1,1]
matrix `x'Libbv=`x'bv[1,2]
matrix `x'sev=e(V)
matrix `x'ALPsev=`x'sev[1,1]^0.5
matrix `x'Libsev=`x'sev[2,2]^0.5
}

foreach x of local pi{
reg `x' ALP if date_q>=tq(1993q2), cluster(PM)
matrix `x'bdifv=e(b)
matrix `x'ALPbdifv=`x'bdifv[1,1]
matrix `x'sedifv=e(V)
matrix `x'ALPsedifv=`x'sedifv[1,1]^0.5
}

* Newey-West, 6 lags

foreach x of local pi{
newey `x' ALP LibNat if date_q>=tq(1993q2), nocons lag(6)
matrix `x'senwv=e(V)
matrix `x'ALPsenwv=`x'senwv[1,1]^0.5
matrix `x'Libsenwv=`x'senwv[2,2]^0.5
}

foreach x of local pi{
newey `x' ALP if date_q>=tq(1993q2), lag(6)
matrix `x'bdifnwv=e(b)
matrix `x'ALPbdifnwv=`x'bdifnwv[1,1]
matrix `x'sedifnwv=e(V)
matrix `x'ALPsedifnwv=`x'sedifnwv[1,1]^0.5
}

matrix gned=[dlGNEDALPb,dlGNEDALPse,dlGNEDALPsenw,dlGNEDLibb,dlGNEDLibse,dlGNEDLibsenw, dlGNEDALPbdif, dlGNEDALPsedif, dlGNEDALPsedifnw]
matrix cpi=[dlCPIALPb,dlCPIALPse,dlCPIALPsenw,dlCPILibb,dlCPILibse,dlCPILibsenw, dlCPIALPbdif, dlCPIALPsedif, dlCPIALPsedifnw]

matrix gnedv=[dlGNEDALPbv,dlGNEDALPsev,dlGNEDALPsenwv,dlGNEDLibbv,dlGNEDLibsev,dlGNEDLibsenwv, dlGNEDALPbdifv, dlGNEDALPsedifv, dlGNEDALPsedifnwv]
matrix cpiv=[dlCPIALPbv,dlCPIALPsev,dlCPIALPsenwv,dlCPILibbv,dlCPILibsev,dlCPILibsenwv, dlCPIALPbdifv, dlCPIALPsedifv, dlCPIALPsedifnwv]

matrix party_pi = [cpi\gned\cpiv\gnedv]
putexcel set "Results_Australia.xls", sheet("Australia", replace) modify
putexcel C2=matrix(party_pi)
