* ------------------------------------------------------------------------------
* United States: Inflation by party
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Directory to save output
global mystart `"C:\Users\z3504163"'
cd "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/US"

* Load data
import excel using "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/US/Inflation measures.xls", sheet("Quarterly") cellrange(B1:J282) firstrow clear

* Construct quarterly date variable
gen year = year(date)
gen month = month(date)
gen quarter = 1 if month==3
replace quarter = 2 if month==6
replace quarter = 3 if month==9
replace quarter = 4 if month==12
gen date_q = yq(year,quarter)
format date_q %tq
order date_q
drop year month quarter date

* Declare time series
tsset date_q

* ------------------------------------------------------------------------------
* Construct data
* ------------------------------------------------------------------------------

* Inflation measures
gen dlGDPDEF = 400*log(GDPDEF/L.GDPDEF)
gen dlPCECTPI = 400*log(PCECTPI/L.PCECTPI)
gen dlCPIAUCSL = 400*log(CPIAUCSL/L.CPIAUCSL)
gen dlCPILFENS = 400*log(CPILFENS/L.CPILFENS)
gen dlPCEPILFE = 400*log(PCEPILFE/L.PCEPILFE)

local pi dlPCECTPI dlCPIAUCSL dlGDPDEF

* Party
gen Dem = 0
replace Dem = 1 if Party=="D"
gen Rep = 0
replace Rep = 1 if Party=="R"

* ------------------------------------------------------------------------------
* Regressions, full sample
* ------------------------------------------------------------------------------

* Clustered by presidential term
foreach x of local pi{
reg `x' Dem Rep if date_q>=tq(1949q2), nocons cluster(Term)
matrix `x'b=e(b)
matrix `x'Demb=`x'b[1,1]
matrix `x'Repb=`x'b[1,2]
matrix `x'se=e(V)
matrix `x'Demse=`x'se[1,1]^0.5
matrix `x'Repse=`x'se[2,2]^0.5
}

foreach x of local pi{
reg `x' Dem if date_q>=tq(1949q2), cluster(Term)
matrix `x'bdif=e(b)
matrix `x'Dembdif=`x'bdif[1,1]
matrix `x'sedif=e(V)
matrix `x'Demsedif=`x'sedif[1,1]^0.5
}

* Newey-West, 6 lags

foreach x of local pi{
newey `x' Dem Rep if date_q>=tq(1949q2), nocons lag(6)
matrix `x'senw=e(V)
matrix `x'Demsenw=`x'senw[1,1]^0.5
matrix `x'Repsenw=`x'senw[2,2]^0.5
}

foreach x of local pi{
newey `x' Dem if date_q>=tq(1949q2), lag(6)
matrix `x'bdifnw=e(b)
matrix `x'Dembdifnw=`x'bdifnw[1,1]
matrix `x'sedifnw=e(V)
matrix `x'Demsedifnw=`x'sedifnw[1,1]^0.5
}

* ------------------------------------------------------------------------------
* Regressions, post 1980
* ------------------------------------------------------------------------------
* Volcker became Fed president in August 1979

* Clustered by presidential term
foreach x of local pi{
reg `x' Dem Rep if date_q>=tq(1980q1), nocons cluster(Term)
matrix `x'bv=e(b)
matrix `x'Dembv=`x'bv[1,1]
matrix `x'Repbv=`x'bv[1,2]
matrix `x'sev=e(V)
matrix `x'Demsev=`x'sev[1,1]^0.5
matrix `x'Repsev=`x'sev[2,2]^0.5
}

foreach x of local pi{
reg `x' Dem if date_q>=tq(1980q1), cluster(Term)
matrix `x'bdifv=e(b)
matrix `x'Dembdifv=`x'bdifv[1,1]
matrix `x'sedifv=e(V)
matrix `x'Demsedifv=`x'sedifv[1,1]^0.5
}

* Newey-West, 6 lags

foreach x of local pi{
newey `x' Dem Rep if date_q>=tq(1980q1), nocons lag(6)
matrix `x'senwv=e(V)
matrix `x'Demsenwv=`x'senwv[1,1]^0.5
matrix `x'Repsenwv=`x'senwv[2,2]^0.5
}

foreach x of local pi{
newey `x' Dem if date_q>=tq(1980q1), lag(6)
matrix `x'bdifnwv=e(b)
matrix `x'Dembdifnwv=`x'bdifnwv[1,1]
matrix `x'sedifnwv=e(V)
matrix `x'Demsedifnwv=`x'sedifnwv[1,1]^0.5
}

matrix pce=[dlPCECTPIDemb,dlPCECTPIDemse,dlPCECTPIDemsenw,dlPCECTPIRepb,dlPCECTPIRepse,dlPCECTPIRepsenw, dlPCECTPIDembdif, dlPCECTPIDemsedif, dlPCECTPIDemsedifnw]
matrix cpi=[dlCPIAUCSLDemb,dlCPIAUCSLDemse,dlCPIAUCSLDemsenw,dlCPIAUCSLRepb,dlCPIAUCSLRepse,dlCPIAUCSLRepsenw, dlCPIAUCSLDembdif, dlCPIAUCSLDemsedif, dlCPIAUCSLDemsedifnw]
matrix gdpdef=[dlGDPDEFDemb,dlGDPDEFDemse,dlGDPDEFDemsenw,dlGDPDEFRepb,dlGDPDEFRepse,dlGDPDEFRepsenw, dlGDPDEFDembdif, dlGDPDEFDemsedif, dlGDPDEFDemsedifnw]

matrix pcev=[dlPCECTPIDembv,dlPCECTPIDemsev,dlPCECTPIDemsenwv,dlPCECTPIRepbv,dlPCECTPIRepsev,dlPCECTPIRepsenwv, dlPCECTPIDembdifv, dlPCECTPIDemsedifv, dlPCECTPIDemsedifnwv]
matrix cpiv=[dlCPIAUCSLDembv,dlCPIAUCSLDemsev,dlCPIAUCSLDemsenwv,dlCPIAUCSLRepbv,dlCPIAUCSLRepsev,dlCPIAUCSLRepsenwv, dlCPIAUCSLDembdifv, dlCPIAUCSLDemsedifv, dlCPIAUCSLDemsedifnwv]
matrix gdpdefv=[dlGDPDEFDembv,dlGDPDEFDemsev,dlGDPDEFDemsenwv,dlGDPDEFRepbv,dlGDPDEFRepsev,dlGDPDEFRepsenwv, dlGDPDEFDembdifv, dlGDPDEFDemsedifv, dlGDPDEFDemsedifnwv]
matrix party_pi = [pce\cpi\gdpdef\pcev\cpiv\gdpdefv]
putexcel set "Results.xls", sheet("US", replace) modify
putexcel C2=matrix(party_pi)

