* ------------------------------------------------------------------------------
* Presidential rankings and inflation performance
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Directory to save output
cd "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/US"

* ------------------------------------------------------------------------------
* Load and organise data
* ------------------------------------------------------------------------------

* Load rankings
import excel using "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/US/Rankings.xlsx", sheet("Rankings") cellrange(A2:C45) firstrow clear
save presidents.dta, replace

* Load other data
import excel using "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/US/Inflation measures.xls", sheet("Quarterly") cellrange(B1:J282) firstrow clear
gen year = year(date)
gen month = month(date)
gen quarter = 1 if month==3
replace quarter = 2 if month==6
replace quarter = 3 if month==9
replace quarter = 4 if month==12
gen date_q = yq(year,quarter)
format date_q %tq
order date_q
drop year month quarter date

* Merge data
merge m:1 President using presidents.dta
keep if _merge==3
drop _merge
sort date_q
erase presidents.dta

* Declare time series
tsset date_q

* ------------------------------------------------------------------------------
* Average data by president
* ------------------------------------------------------------------------------

* Scores ex-economic management
gen Score_exEcon = Score - Econ
format Score_exEcon %9.0f

* Average over presidents
gen n = 1
gen GDPDEF_start = GDPDEF
gen GDPDEF_end = GDPDEF
gen PCECTPI_start = PCECTPI
gen PCECTPI_end = PCECTPI
gen CPIAUCSL_start = CPIAUCSL
gen CPIAUCSL_end = CPIAUCSL

collapse (first) date_q GDPDEF_start PCECTPI_start CPIAUCSL_start Score Score_exEcon (last) GDPDEF_end PCECTPI_end CPIAUCSL_end (sum) n, by(President)

* Annualised average inflation
gen dGDPDEF = ((GDPDEF_end/GDPDEF_start)^(4/(n-1)))*100-100
gen dPCECTPI = ((PCECTPI_end/PCECTPI_start)^(4/(n-1)))*100-100
gen dCPIAUCSL = ((CPIAUCSL_end/CPIAUCSL_start)^(4/(n-1)))*100-100

format dGDPDEF %9.1f
format dPCECTPI %9.1f
format dCPIAUCSL %9.1f

* ------------------------------------------------------------------------------
* Rankings
* ------------------------------------------------------------------------------

* Select sample
*keep if date_q>=tq(1947q1)

gsort -Score_exEcon
list President Score Score_exEcon dPCECTPI dCPIAUCSL dGDPDEF
